@@ -54,6 +54,7 @@ class StickProtocol():
         user.save()
         self.Device.objects.create(user=user, deviceId=data['deviceId'], name=data['deviceName'])
         Party.objects.create(user=user)
+        Party.objects.create(user=user, self=True)
 
     def process_pre_keys(self, data, user):
         """
@@ -208,7 +209,7 @@ class StickProtocol():
                 key = {'id': senderKey.keyId, 'key': senderKey.key, 'step': senderKey.step, 'identityKeyId': senderKey.identityKey.keyId}
         # SenderKey does not exist, send a `PendingKey` request to the target user to upload their key,
         # through a realtime database.
-        else:
+        else: # todo: refactor firebase out?
             phone = self.User.objects.get(id=memberId).phone
             isDev = data['isDev']
             firebase_ref = FIREBASE_REF_DEV if isDev else FIREBASE_REF
@@ -285,7 +286,8 @@ class StickProtocol():
             partyId = data['partyId']
         else:  # Sharing to the currentUser's party (currentUsers' profile)
             membersIds = connections_ids
-            partyId = Party.objects.get(user=user).id
+            isSelf = data['type'] == 'self'
+            partyId = Party.objects.get(user=user, self=isSelf).id
         dict = {}
         bundlesToFetch = []
         responseDict = {}
